# UDG - Universal Data Graph

1. Root - definitions and static methods
2. Keyed - wrap MutableMapping with caching
3. Verifiable - codecs and hashing
4. Node - parent and child
5. Child - pull configuration from parent
6. Folder - child whose children are in a directory

Codec: YAML configuration for converting to/from quilt3 synta
